@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2010-2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2010-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -21,6 +21,8 @@ import time
 from os import path
 from random import choice
 import string
+import glob
+import shutil
 from time import sleep
 from calculate.core.server.func import MethodsInterface
 from calculate.lib.utils.files import (pathJoin,
@@ -543,3 +545,19 @@ class Install(MethodsInterface):
         """
         distr.close()
         return True
+
+    def drop_xorg_logs(self):
+        """
+        Сбросить логи загрузки xorg сервера
+        """
+        for fn in glob.glob("/var/log/Xorg.*.log"):
+            new_name = "%s.old" % fn
+            if path.exists(new_name):
+                os.unlink(new_name)
+            shutil.move(fn, new_name)
+        return True
+
+    def init_themes(self):
+        self.clVars.Get('cl_splash_image_hash')
+        self.clVars.Get('cl_grub_image_hash')
+        return True
